function alignSpondee(wavfile,labfile,word)
% alignSpondee(wavfile, labfile, word)
%    Take a wavfile of a spondee word and write an HTK-format label 
%    file containing an estimated phone alignment.  The orthography 
%    of the word is inferred from the filename, or specified as <word>.
% 2006-10-26 dpwe@ee.columbia.edu

[path,name,ext] = fileparts(wavfile);
if nargin < 2
  labfile = fullfile(path,[name, '.lab']);
end
if nargin < 3
  lastminus = max([0,find(name == '-')]);
  word = name(lastminus+1:end);
end

% Get pronunciations
[prons, probs] = spondee2pron(word);
disp([num2str(length(prons)),' prons found for "',word,'".']);

% Create feature file
tempwav = fullfile(path,[name,'-16k.wav']);
tempmfc = fullfile(path,[name,'.mfc']);
[d,sr] = wavread(wavfile);
targetsr = 16000;
if sr ~= targetsr
  gg = gcd(sr, targetsr);
  d = resample(d, targetsr/gg, sr/gg);
  sr = targetsr;
end
wavwrite(d,sr,tempwav);

tempscp = 'temp.scp';
tempmlfin = 'in.mlf';
tempmlfout = 'out.mlf';


f = fopen(tempscp,'w');
fprintf(f, [tempwav,' ',tempmfc,'\n']);
fclose(f);

% Execute ftrex
eval(['!HCopy -T 1 -C config_hcopy -S ',tempscp]);

% Construct MFC list and ref mlf

f = fopen(tempscp,'w');
for i = 1:length(prons)
  fprintf(f, [tempmfc,'\n']);
end
fclose(f);

f = fopen(tempmlfin,'w');
fprintf(f, '#!MLF!#\n');
for i = 1:length(prons)
  fprintf(f, ['"*/',name,'.lab"\nh#\n']);
  for j = 1:length(prons{i});
    fprintf(f, [prons{i}{j},'\n']);
  end
  fprintf(f, 'h#\n.\n');
end
fclose(f);

% Run forced alignment
eval(['!HVite -T 1 -C configEDAN -H model/hmm0/macros -H model/hmm0/hmmdefs -S ',tempscp,' -i ',tempmlfout,' -a -p -20 -s 40 -I ',tempmlfin,' dict monophones0']);

% Read back the results
aligns = mlfread(tempmlfout);

% Choose the best one
naligns = length(aligns);
bestalign = 1;
bestscore = aligns(1).totalscore;
for i = 2:naligns
  if aligns(i).totalscore > bestscore
    bestscore = aligns(i).totalscore;
    bestalign = i;
  end
end
labs = aligns(bestalign).label;

htktstep = 1e-7;  % 100ns time unit for HTK labels
timitsrate = 1.0;  % or 16000 for 16 kHz samples
sc = htktstep*timitsrate;

% Write the final labfile
f = fopen(labfile,'w');
for i = 1:length(labs)
  fprintf(f, '%f %f %s\n', labs(i).starttime*sc, labs(i).endtime*sc, labs(i).label);
end
fclose(f);
  

eval(['!rm ',tempwav,' ',tempmfc,' ',tempscp,' ',tempmlfin,' ',tempmlfout]);
