function d = mlfread(mlffile)
%  d = mlfread(mlffile)
%  Read the mlf file named in f into cell array in d.
%  Each element of d is a structure describing one alignment
%  d{i}.name = filename string
%  d{i}.label = array of...
%  d{i}.label(i).startime, endtime, label, score
%
% 2006-10-26 dpwe@ee.columbia.edu

dd = textread(mlffile,'%s','delimiter','\n','whitespace','');

if (strcmp(dd{1},'#!MLF!#')) == 0
  error('not an mlf file');
end

naligns = 0;

linenum = 1;

while length(dd) > linenum
  naligns = naligns + 1;
  linenum = linenum+1;
  d(naligns).name = dd{linenum};
  % pull out all the phone lines until "."
  phonenum = 0;
  totalscore = 0;
  linenum = linenum+1;
  while strcmp(dd{linenum},'.') == 0
    phonenum = phonenum+1;
    spcs = [0, find(dd{linenum} == ' '), length(dd{linenum})];
    val{4} = 0;
    for i = 2:length(spcs)
      val{i-1} = dd{linenum}(spcs(i-1)+1:spcs(i)-1);
    end
    d(naligns).label(phonenum).starttime = str2num(val{1});
    d(naligns).label(phonenum).endtime = str2num(val{2});
    d(naligns).label(phonenum).label = val{3};
    d(naligns).label(phonenum).score = str2num(val{4});
    totalscore = totalscore + d(naligns).label(phonenum).score;
    linenum = linenum+1;
  end
  d(naligns).totalscore = totalscore;
  % skip the terminator line
  linenum = linenum+1;
end
